MenstrualCycleDbHelper class

Properties

database → Future<Database?>
get database instance
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearPeriodLog(String customerId) → Future<int>
Delete past period data
clearPeriodLogAfterSpecificDate(String customerId, String lastLogDate) → Future<int>
Delete past period data from specific date
clearSymptomsLog(String customerId) → Future<int>
Delete all symptoms data
getLastPeriodDate() → Future<String>
Return last periods start date
getLastPeriodDateFromInputDate(String logDate) → Future<String>
Return last periods start date
getPastPeriodDates() → Future<List<String>>
Return range of last periods date
insertCurrentUserDetails({int? periodDuration, int? cycleLength, String? customerId}) → Future<int>
insert current user info
insertDailyLog(Map<String, dynamic> data, String logDate, String customerId) → Future<int>
insert daily logs report based on userId and log date
insertOrUpdatePeriodLog(List selectedPeriodsDate) → Future<void>
insert user's period data on userId and log date
insertPeriodLog(List<DateTime> selectedPeriodsDate) → Future<int>
insert user's period data on userId and log date
isPeriodDateFound(DateTime periodDate) → Future<bool>
Check if found period date
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCurrentUserDetail() → void
get all symptoms list
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → MenstrualCycleDbHelper
final