HormoneData class

Constructors

HormoneData(int day, double estrogen, double progesterone, String phase)

Properties

day → int
final
estrogen → double
final
hashCode → int
The hash code for this object.
no setterinherited
phase → String
final
phaseWithDay → String
no setter
progesterone → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited