LogReport class

Constructors

LogReport({int? mainValue = 0, int? mainIndex = 0, String? type, int? subValue = 0, int? subIndex = 0, int? totalMin = 0, String? finalValue = ""})

Properties

finalValue ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mainIndex ↔ int?
getter/setter pair
mainValue ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subIndex ↔ int?
getter/setter pair
subValue ↔ int?
getter/setter pair
totalMin ↔ int?
getter/setter pair
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited