CycleData class

Constructors

CycleData({String? cycleStartDate, String? cycleEndDate, bool? isCurrentCycle, List<CycleDates>? cycleDates})
CycleData.fromJson(Map<String, dynamic> json)

Properties

cycleDates ↔ List<CycleDates>?
getter/setter pair
cycleEndDate ↔ String?
getter/setter pair
cycleStartDate ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isCurrentCycle ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited