WaterData class

Constructors

WaterData({String? dateTime, double? waterValue, String? waterUnit})

Properties

dateTime ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
waterUnit ↔ String?
getter/setter pair
waterValue ↔ double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited